<!-- This index is generated by /ws/ken/agi.green/agi_green/protocol_http.py - edits will be lost. -->

| File | Description |
| ---- | ----------- |
| [**attributions**](/docs/attributions) | *Attributions - thank you!* |
| [**protocols**](/docs/protocols) | *Summary of protocols.py* |
| [**vue_client**](/docs/vue_client) | *AGI Green Vue client* |
| [**ann**](/docs/ann) | *Symmetry and Discrete Equivariance - ANN architecture for Game of Y* |
| [**bots**](/docs/bots) | *Proposed agent specifications* |
| [**brain**](/docs/brain) | *Getting Started on brain.agi.green* |
| [**cim**](/docs/cim) | *Contention Induced Mitosis* |
| [**combat**](/docs/combat) | *Combat* |
| [**copilot alternatives**](/docs/copilot alternatives) | *My thoughts on various AI coding tools* |
| [**cursor_project**](/docs/cursor_project) | *Project Conventions for Cursor AI* |
| [**gameio**](/docs/gameio) | *Game Communication Protocol* |
| [**gnn**](/docs/gnn) | *GNN Architecture for Game of Y* |
| [**ken**](/docs/ken) | *Résumé* |
| [**models**](/docs/models) | *How models.yaml works* |
| [**othello**](/docs/othello) | *Othello Paper - Ideas* |
| [**overview**](/docs/overview) | *chat.agi.green: Framework Overview and Features Guide* |
| [**positions**](/docs/positions) | *POVNet Position Protocol* |
| [**proposal**](/docs/proposal) | *Proposal* |
| [**protocols**](/docs/protocols) | *Guide for Implementing Protocol Message Handlers* |
| [**pycon**](/docs/pycon) | *[Python US 2024](https://us.pycon.org/2024/) Proposal* |
| [**symmetry**](/docs/symmetry) | *Minor notes:* |
| [**training**](/docs/training) | *Training status* |
| [**training_strategies**](/docs/training_strategies) | *Training Strategies* |
| [**yart**](/docs/yart) | *Yet Another Rendering Tool (YART)* |
